@@ -1,9 +1,9 @@
 package App::diffdb;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-04-22'; # DATE
+our $DATE = '2020-04-23'; # DATE
 our $DIST = 'App-diffdb'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -15,26 +15,6 @@ use Log::ger;
 our %SPEC;
 
 our %args_common = (
-    action => {
-        schema => ['str*', in=>[
-            'list_tables1',
-            'list_tables2',
-            'diff_db',
-        ]],
-        default => 'diff_db',
-        cmdline_aliases => {
-            'tables1' => {
-                summary => 'Shortcut for --action=list_tables1',
-                is_flag=>1,
-                code => sub { $_[0]{action} = 'list_tables1' },
-            },
-            'tables2' => {
-                summary => 'Shortcut for --action=list_tables2',
-                is_flag=>1,
-                code => sub { $_[0]{action} = 'list_tables2' },
-            },
-        },
-    },
     diff_command => {
         schema => 'str*', # XXX prog
         default => 'diff',
@@ -43,16 +23,6 @@ our %args_common = (
         schema => ['str*', in=>['json-one-line', 'json-card']], # XXX yaml, csv, tsv, ...
         default => 'json-one-line',
     },
-
-    # XXX add arg: include table pattern
-    # XXX add arg: exclude table pattern
-    # XXX add arg: include column(s)
-    # XXX add arg: exclude column(s)
-    # XXX add arg: include column pattern
-    # XXX add arg: exclude column pattern
-    # XXX add arg: table sort
-    # XXX add column sort args
-    # XXX add row sort args
 );
 
 our %args_connect_dbi = (
@@ -134,7 +104,29 @@ our %args_connect_sqlite = (
     },
 );
 
-our %args_diff = (
+our %args_diff_common = (
+    include_columns => {
+        'x.name.is_plural' => 1,
+        'x.name.singular' => 'include_column',
+        schema => ['array*', of=>'str*'], # XXX completion
+        cmdline_aliases => {c=>{}},
+        tags => ['category:column-selection'],
+    },
+    exclude_columns => {
+        'x.name.is_plural' => 1,
+        'x.name.singular' => 'exclude_column',
+        schema => ['array*', of=>'str*'], # XXX completion
+        cmdline_aliases => {C=>{}},
+        tags => ['category:column-selection'],
+    },
+
+    order_by => {
+        schema => ['str*'],
+        tags => ['category:row-ordering'],
+    },
+);
+
+our %args_diff_db = (
     include_tables => {
         'x.name.is_plural' => 1,
         'x.name.singular' => 'include_table',
@@ -154,25 +146,26 @@ our %args_diff = (
         schema => 'str*',
         tags => ['category:table-selection'],
     },
+);
 
-    include_columns => {
-        'x.name.is_plural' => 1,
-        'x.name.singular' => 'include_column',
-        schema => ['array*', of=>'str*'], # XXX completion
-        cmdline_aliases => {c=>{}},
-        tags => ['category:column-selection'],
+our %args_diff_dbtable = (
+    table1 => {
+        schema => 'str*',
+        pos => 2,
     },
-    exclude_columns => {
-        'x.name.is_plural' => 1,
-        'x.name.singular' => 'exclude_column',
-        schema => ['array*', of=>'str*'], # XXX completion
-        cmdline_aliases => {C=>{}},
-        tags => ['category:column-selection'],
+    table2 => {
+        schema => 'str*',
+        pos => 3,
     },
-
-    order_by => {
-        schema => ['str*'],
-        tags => ['category:row-ordering'],
+    sql1 => {
+        summary => 'Compare the result of SQL select query, instead of tables',
+        schema => 'str*',
+        tags => ['category:table-selection'],
+    },
+    sql2 => {
+        summary => 'Compare the result of SQL select query, instead of tables',
+        schema => 'str*',
+        tags => ['category:table-selection'],
     },
 );
 
@@ -204,18 +197,7 @@ sub _get_row {
     }
 }
 
-sub _diff_file {
-    require IPC::System::Options;
-
-    my ($self, $fname1, $fname2) = @_;
-    IPC::System::Options::system(
-        {log=>1},
-        $self->{diff_command}, "-u",
-        $fname1, $fname2,
-    );
-}
-
-sub _write_result {
+sub _write_query_result {
     my ($self, $sth, $fh) = @_;
     my $rownum = 0;
     while (1) {
@@ -226,94 +208,76 @@ sub _write_result {
     }
 }
 
-sub _diff_query {
-    my ($self, $query) = @_;
+sub _write_query_to_file {
+    my ($self, $which_dbh, $query, $fname) = @_;
 
-    my $fname1 = "$self->{tempdir}/db1.query";
-  CREATE_FILE1: {
-        open my $fh, ">", $fname1;
-        my $sth = $self->{dbh1}->prepare($query);
-        $sth->execute;
-        $self->_write_result($sth, $fh);
-    };
+    my $dblabel = $which_dbh == 1 ? "db1" : "db2";
+    my $dbh = $which_dbh == 1 ? $self->{dbh1} : $self->{dbh2};
+    $fname //= "$self->{tempdir}/$dblabel.query$which_dbh";
 
-    my $fname2 = "$self->{tempdir}/db2.query";
-  CREATE_FILE2: {
-        open my $fh, ">", $fname2;
-        my $sth = $self->{dbh2}->prepare($query);
-        $sth->execute;
-        $self->_write_result($sth, $fh);
-    };
+    open my $fh, ">", $fname;
 
-    $self->_diff_file($fname1, $fname2);
+    my $sth = $dbh->prepare($query);
+    $sth->execute;
+    $self->_write_query_result($sth, $fh);
+
+    close $fh;
+    return $fname;
 }
 
-sub _diff_table {
+sub _write_table_to_file {
     require DBIx::Diff::Schema;
 
-    my ($self, $table, $table1_exists, $table2_exists) = @_;
+    my ($self, $which_dbh, $table) = @_;
 
-    my $fname1 = "$self->{tempdir}/db1.$table".($table1_exists ? '' : '.doesnt_exist');
+    my $dblabel = $which_dbh == 1 ? "db1" : "db2";
+    my $dbh = $which_dbh == 1 ? $self->{dbh1} : $self->{dbh2};
+    my $fname = "$self->{tempdir}/$dblabel.".(defined $table ? $table : 'doesnt_exist');
     my $order_by = $self->{order_by} // '';
 
-  CREATE_FILE1: {
-        open my $fh, ">", $fname1;
-        last unless $table1_exists;
-
-        my @columns;
-      COLUMN:
-        for my $column (DBIx::Diff::Schema::list_columns($self->{dbh1}, $table)) {
-            if ($self->{include_columns} && @{ $self->{include_columns} }) {
-                next COLUMN unless grep { $column->{COLUMN_NAME} eq $_ } @{ $self->{include_columns} };
-            }
-            if ($self->{exclude_columns} && @{ $self->{exclude_columns} }) {
-                next COLUMN if grep { $column->{COLUMN_NAME} eq $_ } @{ $self->{exclude_columns} };
-            }
-            push @columns, $column;
-        }
-        die "No columns to select" unless @columns;
-
-        unless (length $order_by) {
-            my @indexes = grep { $_->{is_unique} }
-                DBIx::Diff::Schema::list_table_indexes(
-            $self->{dbh1}, $table);
-            if (@indexes) {
-                $order_by = join(",", map {qq("$_")} @{ $indexes[0]{columns} });
-            }
-        }
-        my $sth = $self->{dbh1}->prepare(
-            "SELECT ".join(",", map {qq("$_->{COLUMN_NAME}")} @columns).
-                " FROM \"$table\"".($order_by ? " ORDER BY $order_by" : ""));
-        $sth->execute;
-        $self->_write_result($sth, $fh);
+    unless (defined $table) {
+        open my $fh, ">", $fname;
+        close $fh;
+        return $fname;
     }
 
-    my $fname2 = "$self->{tempdir}/db2.$table".($table2_exists ? '' : '.doesnt_exist');
-  CREATE_FILE2: {
-        open my $fh, ">", $fname2;
-        last unless $table2_exists;
+    log_trace "Writing $dblabel table '$table' to temporary file '$fname' ...";
 
-        my @columns;
-      COLUMN:
-        for my $column (DBIx::Diff::Schema::list_columns($self->{dbh2}, $table)) {
-            if ($self->{include_columns} && @{ $self->{include_columns} }) {
-                next COLUMN unless grep { $column->{COLUMN_NAME} eq $_ } @{ $self->{include_columns} };
-            }
-            if ($self->{exclude_columns} && @{ $self->{exclude_columns} }) {
-                next COLUMN if grep { $column->{COLUMN_NAME} eq $_ } @{ $self->{exclude_columns} };
-            }
-            push @columns, $column;
+    my @columns;
+  COLUMN:
+    for my $column (DBIx::Diff::Schema::list_columns($dbh, $table)) {
+        if ($self->{include_columns} && @{ $self->{include_columns} }) {
+            next COLUMN unless grep { $column->{COLUMN_NAME} eq $_ } @{ $self->{include_columns} };
         }
-        die "No columns to select" unless @columns;
-
-        my $sth = $self->{dbh2}->prepare(
-            "SELECT ".join(",", map {qq("$_->{COLUMN_NAME}")} @columns).
-                " FROM \"$table\"".($order_by ? " ORDER BY $order_by" : ""));
-        $sth->execute;
-        $self->_write_result($sth, $fh);
+        if ($self->{exclude_columns} && @{ $self->{exclude_columns} }) {
+            next COLUMN if grep { $column->{COLUMN_NAME} eq $_ } @{ $self->{exclude_columns} };
+        }
+        push @columns, $column;
     }
+    die "No columns to select for table '$table' ($dblabel)" unless @columns;
 
-    $self->_diff_file($fname1, $fname2);
+    unless (length $order_by) {
+        my @indexes = grep { $_->{is_unique} }
+            DBIx::Diff::Schema::list_indexes($dbh, $table);
+        if (@indexes) {
+            $order_by = join(",", map {qq($_)} @{ $indexes[0]{columns} });
+        }
+    }
+    my $query =
+        "SELECT ".join(",", map {qq($_->{COLUMN_NAME})} @columns).
+        " FROM $table".($order_by ? " ORDER BY $order_by" : "");
+    $self->_write_query_to_file($which_dbh, $query, $fname);
+}
+
+sub _diff_files {
+    require IPC::System::Options;
+
+    my ($self, $fname1, $fname2) = @_;
+    IPC::System::Options::system(
+        {log=>1, exit_code_success_criteria=>[0,1]},
+        $self->{diff_command}, "-u",
+        $fname1, $fname2,
+    );
 }
 
 sub _diff_db {
@@ -321,6 +285,22 @@ sub _diff_db {
 
     my $self = shift;
 
+    if (defined $self->{sql}) {
+        if ($self->{dbh1} == $self->{dbh2}) {
+            return [304, "The same query from the same database"];
+        }
+        my $fname1 = $self->_write_query_to_file(1, $self->{sql});
+        my $fname2 = $self->_write_query_to_file(2, $self->{sql});
+        $self->_diff_files($fname1, $fname2);
+        return [200];
+    }
+
+    if ($self->{dbh1} == $self->{dbh2}) {
+        return [304, "The same table(s) from the same database"];
+    }
+
+    # now the case that is left is to diff one or more tables from two dbs
+
     my @tables1 = DBIx::Diff::Schema::list_tables($self->{dbh1});
     my @tables2 = DBIx::Diff::Schema::list_tables($self->{dbh2});
 
@@ -336,38 +316,25 @@ sub _diff_db {
         sort @all_tables;
     };
 
-  SQL:
-    {
-        last unless $self->{sql};
-        $self->_diff_query($self->{sql});
-    }
-
   TABLE:
-    {
-        last if $self->{sql};
-        for my $table (@all_tables) {
-            if ($self->{include_tables} && @{ $self->{include_tables} }) {
-                unless (grep { $_ eq $table } @{ $self->{include_tables} }) {
-                    log_trace "Skipping table $table (not in include_tables)";
-                    next TABLE;
-                }
-            }
-            if ($self->{exclude_tables} && @{ $self->{exclude_tables} }) {
-                if (grep { $_ eq $table } @{ $self->{exclude_tables} }) {
-                    log_trace "Skipping table $table (in exclude_tables)";
-                    next TABLE;
-                }
-            }
-            my $in_db1 = grep { $_ eq $table } @tables1;
-            my $in_db2 = grep { $_ eq $table } @tables2;
-            if ($in_db1 && $in_db2) {
-                $self->_diff_table($table, 1, 1);
-            } elsif (!$in_db2) {
-                $self->_diff_table($table, 1, 0);
-            } else {
-                $self->_diff_table($table, 0, 1);
+    for my $table (@all_tables) {
+        if ($self->{include_tables} && @{ $self->{include_tables} }) {
+            unless (grep { $_ eq $table } @{ $self->{include_tables} }) {
+                log_trace "Skipping table $table (not in include_tables)";
+                next TABLE;
             }
         }
+        if ($self->{exclude_tables} && @{ $self->{exclude_tables} }) {
+            if (grep { $_ eq $table } @{ $self->{exclude_tables} }) {
+                log_trace "Skipping table $table (in exclude_tables)";
+                next TABLE;
+            }
+        }
+        my $in_db1 = grep { $_ eq $table } @tables1;
+        my $in_db2 = grep { $_ eq $table } @tables2;
+        my $fname1 = $self->_write_table_to_file(1, $in_db1 ? $table : undef);
+        my $fname2 = $self->_write_table_to_file(2, $in_db2 ? $table : undef);
+        $self->_diff_files($fname1, $fname2);
     }
 
     [200];
@@ -385,24 +352,17 @@ _
     args => {
         %args_common,
         %args_connect_dbi,
-        %args_diff,
+        %args_diff_common,
+        %args_diff_db,
     },
 
     "cmdline.skip_format" => 1,
-
-    args_rels => {
-    },
-
-    links => [
-        {url=>'prog:diff'},
-    ],
 };
 sub diffdb {
     require DBI;
     require File::Temp;
 
     my %args = @_;
-    my $action = delete $args{action};
     my $self = bless {%args}, __PACKAGE__;
 
     unless ($self->{dbh1}) {
@@ -410,14 +370,6 @@ sub diffdb {
             DBI->connect($args{dsn1}, $args{user1}, $args{password1},
                          {RaiseError=>1});
     }
-    if ($action eq 'list_tables1') {
-        require DBIx::Diff::Schema;
-        for (DBIx::Diff::Schema::list_tables($self->{dbh1})) {
-            s/.+\.//; # ignore schema for now
-            print "$_\n";
-        }
-        return [200];
-    }
 
     unless ($self->{dbh2}) {
         $self->{dbh2} =
@@ -426,21 +378,13 @@ sub diffdb {
                          $args{password2} // $args{password1},
                          {RaiseError=>1});
     }
-    if ($action eq 'list_tables2') {
-        require DBIx::Diff::Schema;
-        for (DBIx::Diff::Schema::list_tables($self->{dbh2})) {
-            s/.+\.//; # ignore schema for now
-            print "$_\n";
-        }
-        return [200];
-    }
 
-    return [400, "Please specify dsn1/dbh1 and dsn2/dbh2"]
+    return [400, "Please specify at least dsn1/dbh1 AND dsn2/dbh2"]
         unless $self->{dbh1} && $self->{dbh2};
 
     $self->{tempdir} = File::Temp::tempdir(CLEANUP => $ENV{DEBUG});
     $self->{diff_command} //= 'diff';
-    $self->{row_as} //= 'one-line-json';
+    $self->{row_as} //= 'json-one-line';
     $self->_diff_db;
 }
 
@@ -456,23 +400,20 @@ _
     args => {
         %args_common,
         %args_connect_sqlite,
-        %args_diff,
+        %args_diff_common,
+        %args_diff_db,
     },
 
     "cmdline.skip_format" => 1,
 
     args_rels => {
     },
-
-    links => [
-        {url=>'prog:diff'},
-    ],
 };
 sub diffdb_sqlite {
     my %args = @_;
 
-    my $dsn1 = "dbi:SQLite:dbname=".delete($args{dbpath1});
-    my $dsn2 = "dbi:SQLite:dbname=".delete($args{dbpath2});
+    my $dsn1 = defined $args{dbpath1} ? "dbi:SQLite:dbname=".delete($args{dbpath1}) : undef;
+    my $dsn2 = defined $args{dbpath2} ? "dbi:SQLite:dbname=".delete($args{dbpath2}) : undef;
     diffdb(
         %args,
         dsn1 => $dsn1,
@@ -480,6 +421,117 @@ sub diffdb_sqlite {
     );
 }
 
+sub _diff_dbtable {
+    my $self = shift;
+
+    if (defined $self->{sql1}) {
+        my $fname1 = $self->_write_query_to_file(1, $self->{sql1});
+        my $fname2 = $self->_write_query_to_file(2, $self->{sql2});
+        $self->_diff_files($fname1, $fname2);
+        return [200];
+    }
+
+    if (defined $self->{table1}) {
+        if ($self->{dbh1} == $self->{dbh2} && $self->{table1} eq $self->{table2}) {
+            return [304, "The same table from the same database"];
+        }
+        my $fname1 = $self->_write_table_to_file(1, $self->{table1});
+        my $fname2 = $self->_write_table_to_file(2, $self->{table2});
+        $self->_diff_files($fname1, $fname2);
+        return [200];
+    }
+
+    # should not be reached
+    die "Please specify either SQL or table";
+}
+
+$SPEC{diffdbtable} = {
+    v => 1.1,
+    summary => 'Compare two database tables, line by line',
+    'description.alt.env.cmdline' => <<'_',
+
+This utility compares two database tables and displays the result as the
+familiar colored unified-style diff.
+
+_
+    args => {
+        %args_common,
+        %args_connect_dbi,
+        %args_diff_common,
+        %args_diff_dbtable,
+    },
+
+    "cmdline.skip_format" => 1,
+
+    args_rels => {
+    },
+};
+sub diffdbtable {
+    require DBI;
+    require File::Temp;
+
+    my %args = @_;
+    my $self = bless {%args}, __PACKAGE__;
+
+    unless ($self->{dbh1}) {
+        $self->{dbh1} =
+            DBI->connect($args{dsn1}, $args{user1}, $args{password1},
+                         {RaiseError=>1});
+    }
+
+    unless ($self->{dbh2}) {
+        if ($args{dsn2}) {
+            $self->{dbh2} =
+                DBI->connect($args{dsn2},
+                             $args{user2} // $args{user1},
+                             $args{password2} // $args{password1},
+                             {RaiseError=>1});
+        } else {
+            $self->{dbh2} = $self->{dbh1};
+        }
+    }
+
+    return [400, "Please specify at least dsn1/dbh1"]
+        unless $self->{dbh1} && $self->{dbh2};
+
+    $self->{tempdir} = File::Temp::tempdir(CLEANUP => $ENV{DEBUG});
+    $self->{diff_command} //= 'diff';
+    $self->{row_as} //= 'json-one-line';
+    $self->{table2} //= $self->{table1};
+    $self->{sql2} //= $self->{sql1};
+    $self->_diff_dbtable;
+}
+
+$SPEC{diffdbtable_sqlite} = {
+    v => 1.1,
+    summary => 'Compare two SQLite database tables, line by line',
+    'description.alt.env.cmdline' => <<'_',
+
+This utility compares two SQLite database tables and displays the result as the
+familiar colored unified-style diff.
+
+_
+    args => {
+        %args_common,
+        %args_connect_sqlite,
+        %args_diff_common,
+        %args_diff_dbtable,
+    },
+
+    "cmdline.skip_format" => 1,
+};
+sub diffdbtable_sqlite {
+    my %args = @_;
+
+    my $dsn1 = "dbi:SQLite:dbname=".delete($args{dbpath1});
+    my $dsn2; $dsn2 = "dbi:SQLite:dbname=".delete($args{dbpath2}) if defined $args{dbpath2};
+    diffdbtable(
+        %args,
+        dsn1 => $dsn1,
+        dsn2 => $dsn2,
+    );
+}
+
 1;
 # ABSTRACT: Compare two databases, line by line
 
@@ -495,7 +547,7 @@ App::diffdb - Compare two databases, line by line
 
 =head1 VERSION
 
-This document describes version 0.002 of App::diffdb (from Perl distribution App-diffdb), released on 2020-04-22.
+This document describes version 0.003 of App::diffdb (from Perl distribution App-diffdb), released on 2020-04-23.
 
 =head1 SYNOPSIS
 
@@ -518,8 +570,6 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<action> => I<str> (default: "diff_db")
-
 =item * B<dbh1> => I<obj>
 
 Alternative to specifying dsn1E<sol>user1E<sol>password1.
@@ -602,8 +652,6 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<action> => I<str> (default: "diff_db")
-
 =item * B<dbpath1> => I<filename>
 
 First SQLite database file.
@@ -631,6 +679,152 @@ Second SQLite database file.
 Compare the result of SQL select query, instead of tables.
 
 
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (payload) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+
+=head2 diffdbtable
+
+Usage:
+
+ diffdbtable(%args) -> [status, msg, payload, meta]
+
+Compare two database tables, line by line.
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<dbh1> => I<obj>
+
+Alternative to specifying dsn1E<sol>user1E<sol>password1.
+
+=item * B<dbh2> => I<obj>
+
+Alternative to specifying dsn2E<sol>user2E<sol>password2.
+
+=item * B<diff_command> => I<str> (default: "diff")
+
+=item * B<dsn1> => I<str>
+
+DBI data source, e.g. "dbi:SQLite:dbname=E<sol>pathE<sol>toE<sol>db1.db".
+
+=item * B<dsn2> => I<str>
+
+DBI data source, e.g. "dbi:SQLite:dbname=E<sol>pathE<sol>toE<sol>db1.db".
+
+=item * B<exclude_columns> => I<array[str]>
+
+=item * B<include_columns> => I<array[str]>
+
+=item * B<order_by> => I<str>
+
+=item * B<password1> => I<str>
+
+You might want to specify this parameter in a configuration file instead of
+directly as command-line option.
+
+=item * B<password2> => I<str>
+
+Will default to C<password1> if C<password1> is specified.
+
+You might want to specify this parameter in a configuration file instead of
+directly as command-line option.
+
+=item * B<row_as> => I<str> (default: "json-one-line")
+
+=item * B<sql1> => I<str>
+
+Compare the result of SQL select query, instead of tables.
+
+=item * B<sql2> => I<str>
+
+Compare the result of SQL select query, instead of tables.
+
+=item * B<table1> => I<str>
+
+=item * B<table2> => I<str>
+
+=item * B<user1> => I<str>
+
+=item * B<user2> => I<str>
+
+Will default to C<user1> if C<user1> is specified.
+
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (payload) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
+
+=head2 diffdbtable_sqlite
+
+Usage:
+
+ diffdbtable_sqlite(%args) -> [status, msg, payload, meta]
+
+Compare two SQLite database tables, line by line.
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<dbpath1> => I<filename>
+
+First SQLite database file.
+
+=item * B<dbpath2> => I<filename>
+
+Second SQLite database file.
+
+=item * B<diff_command> => I<str> (default: "diff")
+
+=item * B<exclude_columns> => I<array[str]>
+
+=item * B<include_columns> => I<array[str]>
+
+=item * B<order_by> => I<str>
+
+=item * B<row_as> => I<str> (default: "json-one-line")
+
+=item * B<sql1> => I<str>
+
+Compare the result of SQL select query, instead of tables.
+
+=item * B<sql2> => I<str>
+
+Compare the result of SQL select query, instead of tables.
+
+=item * B<table1> => I<str>
+
+=item * B<table2> => I<str>
+
+
 =back
 
 Returns an enveloped result (an array).
@@ -672,9 +866,6 @@ feature.
 L<diff-db-schema> from L<App::DiffDBSchemaUtils> which presents the result
 structure from L<DBIx::Diff::Schema> directly.
 
-
-L<diff>.
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
